@@ -25,15 +25,18 @@ def _GET_CONST(attr, default_value):
 
 # determine XDG compatible paths
 for xdg_var, var_name, fallback_dir in (
-        ('XDG_CONFIG_HOME', 'USER_CONFIG_PATH', '~/.config'),
-        ('XDG_DATA_HOME', 'USER_DATA_PATH', '~/.local/share')):
+    ("XDG_CONFIG_HOME", "USER_CONFIG_PATH", "~/.config"),
+    ("XDG_DATA_HOME", "USER_DATA_PATH", "~/.local/share"),
+):
     setattr(
-        _module, var_name,
-        os.path.join(os.environ.get(xdg_var, os.path.expanduser(fallback_dir)), 'pkgdev'))
+        _module,
+        var_name,
+        os.path.join(os.environ.get(xdg_var, os.path.expanduser(fallback_dir)), "pkgdev"),
+    )
 
-REPO_PATH = _GET_CONST('REPO_PATH', _reporoot)
-DATA_PATH = _GET_CONST('DATA_PATH', '%(REPO_PATH)s/data')
+REPO_PATH = _GET_CONST("REPO_PATH", _reporoot)
+DATA_PATH = _GET_CONST("DATA_PATH", "%(REPO_PATH)s/data")
 
-USER_CONF_FILE = os.path.join(getattr(_module, 'USER_CONFIG_PATH'), 'pkgdev.conf')
-SYSTEM_CONF_FILE = '/etc/pkgdev/pkgdev.conf'
-BUNDLED_CONF_FILE = os.path.join(DATA_PATH, 'pkgdev.conf')
+USER_CONF_FILE = os.path.join(getattr(_module, "USER_CONFIG_PATH"), "pkgdev.conf")
+SYSTEM_CONF_FILE = "/etc/pkgdev/pkgdev.conf"
+BUNDLED_CONF_FILE = os.path.join(DATA_PATH, "pkgdev.conf")
