@@ -2,33 +2,42 @@
 
 import contextlib
 import json
+import os
+import shlex
+import subprocess
 import sys
+import tempfile
+import tomllib
 import urllib.request as urllib
 from collections import defaultdict
+from datetime import datetime
 from functools import partial
 from itertools import chain
-from pathlib import Path
 from urllib.parse import urlencode
 
 from pkgcheck import const as pkgcheck_const
 from pkgcheck.addons import ArchesAddon, init_addon
 from pkgcheck.addons.profiles import ProfileAddon
-from pkgcheck.checks import visibility
+from pkgcheck.addons.git import GitAddon, GitAddedRepo, GitModifiedRepo
+from pkgcheck.checks import visibility, stablereq
 from pkgcheck.scripts import argparse_actions
 from pkgcore.ebuild.atom import atom
 from pkgcore.ebuild.ebuild_src import package
 from pkgcore.ebuild.errors import MalformedAtom
 from pkgcore.ebuild.misc import sort_keywords
+from pkgcore.ebuild.repo_objs import LocalMetadataXml, ProjectsXml
 from pkgcore.repository import multiplex
 from pkgcore.restrictions import boolean, packages, values
 from pkgcore.test.misc import FakePkg
 from pkgcore.util import commandline, parserestrict
 from snakeoil.cli import arghparse
 from snakeoil.cli.input import userquery
+from snakeoil.data_source import bytes_data_source
 from snakeoil.formatters import Formatter
+from snakeoil.osutils import pjoin
 
 from ..cli import ArgumentParser
-from .argparsers import _determine_cwd_repo, cwd_repo_argparser
+from .argparsers import _determine_cwd_repo, cwd_repo_argparser, BugzillaApiKey
 
 bugs = ArgumentParser(
     prog="pkgdev bugs",
@@ -37,16 +46,7 @@ bugs = ArgumentParser(
     quiet=False,
     parents=(cwd_repo_argparser,),
 )
-bugs.add_argument(
-    "--api-key",
-    metavar="KEY",
-    help="Bugzilla API key",
-    docs="""
-        The Bugzilla API key to use for authentication. WARNING: using this
-        option will expose your API key to other users of the same system.
-        Consider instead saving your API key in a file named ~/.bugz_token.
-    """,
-)
+BugzillaApiKey.mangle_argparser(bugs)
 bugs.add_argument(
     "targets",
     metavar="target",
@@ -59,10 +59,22 @@ bugs.add_argument(
     "--dot",
     help="path file where to save the graph in dot format",
 )
+bugs.add_argument(
+    "--edit-graph",
+    action="store_true",
+    help="open editor to modify the graph before filing bugs",
+    docs="""
+        When this argument is passed, pkgdev will open the graph in the editor
+        (either ``$VISUAL`` or ``$EDITOR``) before filing bugs. The graph is
+        represented in TOML format. After saving and exiting the editor, the
+        tool would use the graph from the file to file bugs.
+    """,
+)
 bugs.add_argument(
     "--auto-cc-arches",
     action=arghparse.CommaSeparatedNegationsAppend,
     default=([], []),
+    metavar="EMAIL",
     help="automatically add CC-ARCHES for the listed email addresses",
     docs="""
         Comma separated list of email addresses, for which automatically add
@@ -70,6 +82,42 @@ bugs.add_argument(
         package is maintainer-needed, always add CC-ARCHES.
     """,
 )
+bugs.add_argument(
+    "--find-by-maintainer",
+    action=arghparse.CommaSeparatedNegationsAppend,
+    default=([], []),
+    metavar="EMAIL",
+    help="collect all packages maintained by the listed email addresses",
+    docs="""
+        Comma separated list of email addresses, for which pkgdev will collect
+        all packages maintained by.
+
+        Note that this flag requires to go over all packages in the repository
+        to find matches, which can be slow (between 1 to 3 seconds).
+    """,
+)
+bugs.add_argument(
+    "--projects",
+    action="store_true",
+    help="include packages maintained by projects",
+    docs="""
+        Include packages maintained by projects, whose members include the
+        emails of maintainers passed to ``--find-by-maintainer``.
+
+        Note that this flag requires to fetch the ``projects.xml`` file from
+        ``https://api.gentoo.org``.
+    """,
+)
+bugs.add_argument(
+    "--filter-stablereqs",
+    action="store_true",
+    help="filter targets for packages with active StableRequest result",
+    docs="""
+        Filter targets passed to pkgdev (command line, stabilization groups,
+        maintainer search, stdin) for packages with active ``StableRequest``
+        result.
+    """,
+)
 bugs.add_argument(
     "--blocks",
     metavar="BUG",
@@ -112,8 +160,11 @@ bugs_state.add_argument(
     help="File rekeywording bugs",
 )
 
+bugs.plugin = bugs
 ArchesAddon.mangle_argparser(bugs)
+GitAddon.mangle_argparser(bugs)
 ProfileAddon.mangle_argparser(bugs)
+stablereq.StableRequestCheck.mangle_argparser(bugs)
 
 
 @bugs.bind_delayed_default(1500, "target_repo")
@@ -121,7 +172,8 @@ def _validate_args(namespace, attr):
     _determine_cwd_repo(bugs, namespace)
     setattr(namespace, attr, namespace.repo)
     setattr(namespace, "verbosity", 1)
-    setattr(namespace, "search_repo", multiplex.tree(*namespace.repo.trees))
+    setattr(namespace, "search_repo", search_repo := multiplex.tree(*namespace.repo.trees))
+    setattr(namespace, "gentoo_repo", search_repo)
     setattr(namespace, "query_caching_freq", "package")
 
 
@@ -156,12 +208,14 @@ def parse_atom(pkg: str):
 
 
 class GraphNode:
-    __slots__ = ("pkgs", "edges", "bugno")
+    __slots__ = ("pkgs", "edges", "bugno", "summary", "cc_arches")
 
     def __init__(self, pkgs: tuple[tuple[package, set[str]], ...], bugno=None):
         self.pkgs = pkgs
         self.edges: set[GraphNode] = set()
         self.bugno = bugno
+        self.summary = ""
+        self.cc_arches = None
 
     def __eq__(self, __o: object):
         return self is __o
@@ -181,6 +235,8 @@ class GraphNode:
 
     @property
     def dot_edge(self):
+        if self.bugno is not None:
+            return f"bug_{self.bugno}"
         return f'"{self.pkgs[0][0].versioned_atom}"'
 
     def cleanup_keywords(self, repo):
@@ -198,26 +254,59 @@ class GraphNode:
                 keywords.clear()
                 keywords.add("*")
 
+    @property
+    def bug_summary(self):
+        if self.summary:
+            return self.summary
+        summary = f"{', '.join(pkg.versioned_atom.cpvstr for pkg, _ in self.pkgs)}: stablereq"
+        if len(summary) > 90 and len(self.pkgs) > 1:
+            return f"{self.pkgs[0][0].versioned_atom.cpvstr} and friends: stablereq"
+        return summary
+
+    @property
+    def node_maintainers(self):
+        return dict.fromkeys(
+            maintainer.email for pkg, _ in self.pkgs for maintainer in pkg.maintainers
+        )
+
+    def should_cc_arches(self, auto_cc_arches: frozenset[str]):
+        if self.cc_arches is not None:
+            return self.cc_arches
+        maintainers = self.node_maintainers
+        return bool(
+            not maintainers or "*" in auto_cc_arches or auto_cc_arches.intersection(maintainers)
+        )
+
     def file_bug(
-        self, api_key: str, auto_cc_arches: frozenset[str], block_bugs: list[int], observer=None
+        self,
+        api_key: str,
+        auto_cc_arches: frozenset[str],
+        block_bugs: list[int],
+        modified_repo: multiplex.tree,
+        observer=None,
     ) -> int:
         if self.bugno is not None:
             return self.bugno
         for dep in self.edges:
             if dep.bugno is None:
-                dep.file_bug(api_key, auto_cc_arches, (), observer)
-        maintainers = dict.fromkeys(
-            maintainer.email for pkg, _ in self.pkgs for maintainer in pkg.maintainers
-        )
-        if not maintainers or "*" in auto_cc_arches or auto_cc_arches.intersection(maintainers):
+                dep.file_bug(api_key, auto_cc_arches, (), modified_repo, observer)
+        maintainers = self.node_maintainers
+        if self.should_cc_arches(auto_cc_arches):
             keywords = ["CC-ARCHES"]
         else:
             keywords = []
         maintainers = tuple(maintainers) or ("maintainer-needed@gentoo.org",)
 
-        summary = f"{', '.join(pkg.versioned_atom.cpvstr for pkg, _ in self.pkgs)}: stablereq"
-        if len(summary) > 90 and len(self.pkgs) > 1:
-            summary = f"{self.pkgs[0][0].versioned_atom.cpvstr} and friends: stablereq"
+        description = ["Please stabilize", ""]
+        if modified_repo is not None:
+            for pkg, _ in self.pkgs:
+                with contextlib.suppress(StopIteration):
+                    match = next(modified_repo.itermatch(pkg.versioned_atom))
+                    modified = datetime.fromtimestamp(match.time)
+                    days_old = (datetime.today() - modified).days
+                    description.append(
+                        f" {pkg.versioned_atom.cpvstr}: no change for {days_old} days, since {modified:%Y-%m-%d}"
+                    )
 
         request_data = dict(
             Bugzilla_api_key=api_key,
@@ -225,8 +314,8 @@ class GraphNode:
             component="Stabilization",
             severity="enhancement",
             version="unspecified",
-            summary=summary,
-            description="Please stabilize",
+            summary=self.bug_summary,
+            description="\n".join(description).strip(),
             keywords=keywords,
             cf_stabilisation_atoms="\n".join(self.lines()),
             assigned_to=maintainers[0],
@@ -256,10 +345,18 @@ class DependencyGraph:
         self.out = out
         self.err = err
         self.options = options
+        disabled, enabled = options.auto_cc_arches
+        self.auto_cc_arches = frozenset(enabled).difference(disabled)
         self.profile_addon: ProfileAddon = init_addon(ProfileAddon, options)
 
         self.nodes: set[GraphNode] = set()
         self.starting_nodes: set[GraphNode] = set()
+        self.targets: tuple[package] = ()
+
+        git_addon = init_addon(GitAddon, options)
+        self.added_repo = git_addon.cached_repo(GitAddedRepo)
+        self.modified_repo = git_addon.cached_repo(GitModifiedRepo)
+        self.stablereq_check = stablereq.StableRequestCheck(self.options, git_addon=git_addon)
 
     def mk_fake_pkg(self, pkg: package, keywords: set[str]):
         return FakePkg(
@@ -271,31 +368,68 @@ class DependencyGraph:
             data={attr: str(getattr(pkg, attr.lower())) for attr in pkg.eapi.dep_keys},
         )
 
-    def find_best_match(self, restrict, pkgset: list[package]) -> package:
+    def find_best_match(self, restrict, pkgset: list[package], prefer_semi_stable=True) -> package:
         restrict = boolean.AndRestriction(
             *restrict,
             packages.PackageRestriction("properties", values.ContainmentMatch("live", negate=True)),
         )
+        # prefer using user selected targets
+        if intersect := tuple(filter(restrict.match, self.targets)):
+            return max(intersect)
         # prefer using already selected packages in graph
         all_pkgs = (pkg for node in self.nodes for pkg, _ in node.pkgs)
         if intersect := tuple(filter(restrict.match, all_pkgs)):
             return max(intersect)
         matches = sorted(filter(restrict.match, pkgset), reverse=True)
+        # prefer package with any stable keyword
+        if prefer_semi_stable:
+            for match in matches:
+                if not all(keyword.startswith("~") for keyword in match.keywords):
+                    return match
+        # prefer package with any keyword
         for match in matches:
-            if not all(keyword.startswith("~") for keyword in match.keywords):
+            if match.keywords:
                 return match
         return matches[0]
 
     def extend_targets_stable_groups(self, groups):
         stabilization_groups = self.options.repo.stabilization_groups
-        search_repo = self.options.search_repo
         for group in groups:
             for pkg in stabilization_groups[group]:
                 try:
-                    yield None, self.find_best_match([pkg], search_repo.match(pkg)).versioned_atom
+                    yield None, pkg
                 except (ValueError, IndexError):
                     self.err.write(f"Unable to find match for {pkg.unversioned_atom}")
 
+    def _extend_projects(self, disabled, enabled):
+        members = defaultdict(set)
+        self.out.write("Fetching projects.xml")
+        self.out.flush()
+        with urllib.urlopen("https://api.gentoo.org/metastructure/projects.xml", timeout=30) as f:
+            for email, project in ProjectsXml(bytes_data_source(f.read())).projects.items():
+                for member in project.members:
+                    members[member.email].add(email)
+
+        disabled = frozenset(disabled).union(*(members[email] for email in disabled))
+        enabled = frozenset(enabled).union(*(members[email] for email in enabled))
+        return disabled, enabled
+
+    def extend_maintainers(self):
+        disabled, enabled = self.options.find_by_maintainer
+        if self.options.projects:
+            disabled, enabled = self._extend_projects(disabled, enabled)
+        emails = frozenset(enabled).difference(disabled)
+        if not emails:
+            return
+        search_repo = self.options.search_repo
+        self.out.write("Searching for packages maintained by: ", ", ".join(emails))
+        self.out.flush()
+        for cat, pkgs in search_repo.packages.items():
+            for pkg in pkgs:
+                xml = LocalMetadataXml(pjoin(search_repo.location[0], cat, pkg, "metadata.xml"))
+                if emails.intersection(m.email for m in xml.maintainers):
+                    yield None, parserestrict.parse_match(f"{cat}/{pkg}")
+
     def _find_dependencies(self, pkg: package, keywords: set[str]):
         check = visibility.VisibilityCheck(self.options, profile_addon=self.profile_addon)
 
@@ -318,20 +452,38 @@ class DependencyGraph:
                         match = self.find_best_match(deps, pkgset)
                     except (ValueError, IndexError):
                         deps_str = " , ".join(map(str, deps))
-                        self.err.error(
+                        bugs.error(
                             f"unable to find match for restrictions: {deps_str}",
+                            status=3,
                         )
-                        raise
                     results[match].add(keyword)
                 yield from results.items()
 
-    def build_full_graph(self, targets: list[package]):
-        check_nodes = [(pkg, set()) for pkg in targets]
+    def load_targets(self, targets: list[tuple[str, str]]):
+        result = []
+        search_repo = self.options.search_repo
+        for _, target in targets:
+            try:
+                pkgset = search_repo.match(target)
+                if self.options.filter_stablereqs:
+                    for res in self.stablereq_check.feed(sorted(pkgset)):
+                        if isinstance(res, stablereq.StableRequest):
+                            target = atom(f"={res.category}/{res.package}-{res.version}")
+                            break
+                    else:  # no stablereq
+                        continue
+                result.append(self.find_best_match([target], pkgset, False))
+            except (ValueError, IndexError):
+                bugs.error(f"Restriction {target} has no match in repository", status=3)
+        self.targets = tuple(result)
+
+    def build_full_graph(self):
+        check_nodes = [(pkg, set(), "") for pkg in self.targets]
 
         vertices: dict[package, GraphNode] = {}
         edges = []
         while len(check_nodes):
-            pkg, keywords = check_nodes.pop(0)
+            pkg, keywords, reason = check_nodes.pop(0)
             if pkg in vertices:
                 vertices[pkg].pkgs[0][1].update(keywords)
                 continue
@@ -341,27 +493,29 @@ class DependencyGraph:
             if pkg_has_stable and not keywords:  # package already done
                 self.out.write(f"Nothing to stable for {pkg.unversioned_atom}")
                 continue
-            assert (
-                keywords
-            ), f"no keywords for {pkg.versioned_atom}, currently unsupported by tool: https://github.com/pkgcore/pkgdev/issues/123"
+            assert keywords, (
+                f"no keywords for {pkg.versioned_atom}, currently unsupported by tool: https://github.com/pkgcore/pkgdev/issues/123"
+            )
             self.nodes.add(new_node := GraphNode(((pkg, keywords),)))
             vertices[pkg] = new_node
+            if reason:
+                reason = f" [added for {reason}]"
             self.out.write(
-                f"Checking {pkg.versioned_atom} on {' '.join(sort_keywords(keywords))!r}"
+                f"Checking {pkg.versioned_atom} on {' '.join(sort_keywords(keywords))!r}{reason}"
             )
             self.out.flush()
 
             for dep, keywords in self._find_dependencies(pkg, keywords):
                 edges.append((pkg, dep))
-                check_nodes.append((dep, keywords))
+                check_nodes.append((dep, keywords, str(pkg.versioned_atom)))
 
         for src, dst in edges:
             vertices[src].edges.add(vertices[dst])
         self.starting_nodes = {
-            vertices[starting_node] for starting_node in targets if starting_node in vertices
+            vertices[starting_node] for starting_node in self.targets if starting_node in vertices
         }
 
-    def output_dot(self, dot_file):
+    def output_dot(self, dot_file: str):
         with open(dot_file, "w") as dot:
             dot.write("digraph {\n")
             dot.write("\trankdir=LR;\n")
@@ -375,6 +529,77 @@ class DependencyGraph:
             dot.write("}\n")
             dot.close()
 
+    def output_graph_toml(self):
+        self.auto_cc_arches
+        bugs = dict(enumerate(self.nodes, start=1))
+        reverse_bugs = {node: bugno for bugno, node in bugs.items()}
+
+        toml = tempfile.NamedTemporaryFile(mode="w", suffix=".toml")
+        for bugno, node in bugs.items():
+            if node.bugno is not None:
+                continue  # already filed
+            toml.write(f"[bug-{bugno}]\n")
+            toml.write(f'summary = "{node.bug_summary}"\n')
+            toml.write(f"cc_arches = {str(node.should_cc_arches(self.auto_cc_arches)).lower()}\n")
+            if node_depends := ", ".join(
+                (f'"bug-{reverse_bugs[dep]}"' if dep.bugno is None else str(dep.bugno))
+                for dep in node.edges
+            ):
+                toml.write(f"depends = [{node_depends}]\n")
+            if node_blocks := ", ".join(
+                f'"bug-{i}"' for i, src in bugs.items() if node in src.edges
+            ):
+                toml.write(f"blocks = [{node_blocks}]\n")
+            for pkg, arches in node.pkgs:
+                try:
+                    match = next(self.modified_repo.itermatch(pkg.versioned_atom))
+                    modified = datetime.fromtimestamp(match.time)
+                    age = (datetime.today() - modified).days
+                    modified_text = f"{modified:%Y-%m-%d} (age {age} days)"
+                except StopIteration:
+                    modified_text = "<unknown>"
+
+                try:
+                    match = next(self.added_repo.itermatch(pkg.versioned_atom))
+                    added = datetime.fromtimestamp(match.time)
+                    age = (datetime.today() - added).days
+                    added_text = f"{added:%Y-%m-%d} (age {age} days)"
+                except StopIteration:
+                    added_text = "<unknown>"
+
+                toml.write(f"# added on {added_text}, last modified on {modified_text}\n")
+                keywords = ", ".join(f'"{x}"' for x in sort_keywords(arches))
+                toml.write(f'"{pkg.versioned_atom}" = [{keywords}]\n')
+            toml.write("\n\n")
+        toml.flush()
+        return toml
+
+    def load_graph_toml(self, toml_file: str):
+        repo = self.options.search_repo
+        with open(toml_file, "rb") as f:
+            data = tomllib.load(f)
+
+        new_bugs: dict[int | str, GraphNode] = {}
+        for node_name, data_node in data.items():
+            pkgs = tuple(
+                (next(repo.itermatch(atom(pkg))), set(keywords))
+                for pkg, keywords in data_node.items()
+                if pkg.startswith("=")
+            )
+            new_bugs[node_name] = GraphNode(pkgs)
+        for node_name, data_node in data.items():
+            new_bugs[node_name].summary = data_node.get("summary", "")
+            new_bugs[node_name].cc_arches = data_node.get("cc_arches", None)
+            for dep in data_node.get("depends", ()):
+                if isinstance(dep, int):
+                    new_bugs[node_name].edges.add(new_bugs.setdefault(dep, GraphNode((), dep)))
+                elif new_bugs.get(dep) is not None:
+                    new_bugs[node_name].edges.add(new_bugs[dep])
+                else:
+                    bugs.error(f"[{node_name}]['depends']: unknown dependency {dep!r}")
+        self.nodes = set(new_bugs.values())
+        self.starting_nodes = {node for node in self.nodes if not node.edges}
+
     def merge_nodes(self, nodes: tuple[GraphNode, ...]) -> GraphNode:
         self.nodes.difference_update(nodes)
         is_start = bool(self.starting_nodes.intersection(nodes))
@@ -413,6 +638,7 @@ class DependencyGraph:
             assert starting_node in self.nodes
             while cycle := self._find_cycles(tuple(self.nodes), [starting_node]):
                 self.out.write("Found cycle: ", " -> ".join(str(n) for n in cycle))
+                start_nodes.difference_update(cycle)
                 new_node = self.merge_nodes(cycle)
                 if starting_node not in self.nodes:
                     starting_node = new_node
@@ -458,7 +684,7 @@ class DependencyGraph:
         params = urlencode(
             {
                 "Bugzilla_api_key": api_key,
-                "include_fields": "id,cf_stabilisation_atoms",
+                "include_fields": "id,cf_stabilisation_atoms,summary",
                 "component": "Stabilization",
                 "resolution": "---",
                 "f1": "cf_stabilisation_atoms",
@@ -492,6 +718,7 @@ class DependencyGraph:
                         f"Found https://bugs.gentoo.org/{node.bugno} for node {node}",
                         self.out.reset,
                     )
+                    self.out.write(" -> bug summary: ", bug["summary"])
                     break
 
     def file_bugs(self, api_key: str, auto_cc_arches: frozenset[str], block_bugs: list[int]):
@@ -505,10 +732,10 @@ class DependencyGraph:
             self.out.flush()
 
         for node in self.starting_nodes:
-            node.file_bug(api_key, auto_cc_arches, block_bugs, observe)
+            node.file_bug(api_key, auto_cc_arches, block_bugs, self.modified_repo, observe)
 
 
-def _load_from_stdin(out: Formatter, err: Formatter):
+def _load_from_stdin(out: Formatter):
     if not sys.stdin.isatty():
         out.warn("No packages were specified, reading from stdin...")
         for line in sys.stdin.readlines():
@@ -517,15 +744,7 @@ def _load_from_stdin(out: Formatter, err: Formatter):
         # reassign stdin to allow interactivity (currently only works for unix)
         sys.stdin = open("/dev/tty")
     else:
-        raise arghparse.ArgumentError(None, "reading from stdin is only valid when piping data in")
-
-
-def _parse_targets(search_repo, targets):
-    for _, target in targets:
-        try:
-            yield max(search_repo.itermatch(target))
-        except ValueError:
-            raise ValueError(f"Restriction {target} has no match in repository")
+        bugs.error("reading from stdin is only valid when piping data in")
 
 
 @bugs.bind_main_func
@@ -533,22 +752,15 @@ def main(options, out: Formatter, err: Formatter):
     search_repo = options.search_repo
     options.targets = options.targets or []
     d = DependencyGraph(out, err, options)
+    options.targets.extend(d.extend_maintainers())
     options.targets.extend(d.extend_targets_stable_groups(options.sets or ()))
     if not options.targets:
-        options.targets = list(_load_from_stdin(out, err))
-    targets = list(_parse_targets(search_repo, options.targets))
-    d.build_full_graph(targets)
+        options.targets = list(_load_from_stdin(out))
+    d.load_targets(options.targets)
+    d.build_full_graph()
+    d.merge_stabilization_groups()
     d.merge_cycles()
     d.merge_new_keywords_children()
-    d.merge_stabilization_groups()
-
-    for node in d.nodes:
-        node.cleanup_keywords(search_repo)
-
-    if options.api_key is None:
-        bugz_token_file = Path.home() / ".bugz_token"
-        if bugz_token_file.is_file:
-            options.api_key = bugz_token_file.read_text().strip()
 
     if not d.nodes:
         out.write(out.fg("red"), "Nothing to do, exiting", out.reset)
@@ -557,9 +769,33 @@ def main(options, out: Formatter, err: Formatter):
     if userquery("Check for open bugs matching current graph?", out, err, default_answer=False):
         d.scan_existing_bugs(options.api_key)
 
+    if options.edit_graph:
+        toml = d.output_graph_toml()
+
+    for node in d.nodes:
+        node.cleanup_keywords(search_repo)
+
     if options.dot is not None:
         d.output_dot(options.dot)
         out.write(out.fg("green"), f"Dot file written to {options.dot}", out.reset)
+        out.flush()
+
+    if options.edit_graph:
+        editor = shlex.split(os.environ.get("VISUAL", os.environ.get("EDITOR", "nano")))
+        try:
+            subprocess.run(editor + [toml.name], check=True)
+        except subprocess.CalledProcessError:
+            bugs.error("failed writing mask comment")
+        except FileNotFoundError:
+            bugs.error(f"nonexistent editor: {editor[0]!r}")
+        d.load_graph_toml(toml.name)
+        for node in d.nodes:
+            node.cleanup_keywords(search_repo)
+
+        if options.dot is not None:
+            d.output_dot(options.dot)
+            out.write(out.fg("green"), f"Dot file written to {options.dot}", out.reset)
+            out.flush()
 
     bugs_count = len(tuple(node for node in d.nodes if node.bugno is None))
     if bugs_count == 0:
