@@ -152,6 +152,36 @@ class TestPkgdevCommitParseArgs:
                 options, _ = tool.parse_args(["commit", opt, "https://bugs.gentoo.org/2"])
                 assert options.footer == {("Closes", "https://bugs.gentoo.org/2")}
 
+            # bug IDs and URLs with good resolutions
+            for opt in ("-c", "--closes"):
+                for values, expected in (
+                    (("", "FIXED", "fiXed"), ""),
+                    (("PKGREMOVED", "pkgRemovEd"), " (pkgremoved)"),
+                    (("OBSOLETE", "obSoleTe"), " (obsolete)"),
+                ):
+                    for value in values:
+                        for bug in "1", "https://bugs.gentoo.org/1":
+                            options, _ = tool.parse_args(["commit", opt, f"{bug}:{value}"])
+                            assert options.footer == {
+                                ("Closes", f"https://bugs.gentoo.org/1{expected}")
+                            }
+
+            # bad bug-resolution pair
+            for opt in ("-c", "--closes"):
+                for value, expected in (
+                    (":", "invalid commit tag"),
+                    (":1", "invalid commit tag"),
+                    (":fixed", "invalid commit tag"),
+                    ("1:invalid", "should be one of"),
+                    ("https://bugs.gentoo.org/1:invalid", "should be one of"),
+                ):
+                    with pytest.raises(SystemExit) as excinfo:
+                        options, _ = tool.parse_args(["commit", opt, value])
+                    assert excinfo.value.code == 2
+                    out, err = capsys.readouterr()
+                    assert not out
+                    assert expected in err
+
             # bad URL
             for opt in ("-b", "-c"):
                 with pytest.raises(SystemExit) as excinfo:
@@ -194,8 +224,10 @@ class TestPkgdevCommit:
 
     def test_empty_repo(self, capsys, repo, make_git_repo):
         git_repo = make_git_repo(repo.location, commit=True)
-        with patch("sys.argv", self.args), pytest.raises(SystemExit) as excinfo, chdir(
-            git_repo.path
+        with (
+            patch("sys.argv", self.args),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
         ):
             self.script()
         assert excinfo.value.code == 2
@@ -212,9 +244,11 @@ class TestPkgdevCommit:
         with open(path, "w") as f:
             f.write("commit1")
 
-        with patch("sys.argv", self.args + ["-u", "-F", path]), pytest.raises(
-            SystemExit
-        ) as excinfo, chdir(git_repo.path):
+        with (
+            patch("sys.argv", self.args + ["-u", "-F", path]),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         assert excinfo.value.code == 0
         commit_msg = git_repo.log(["-1", "--pretty=tformat:%B", "HEAD"])
@@ -222,9 +256,12 @@ class TestPkgdevCommit:
 
         repo.create_ebuild("cat/pkg-1")
         git_repo.add_all("cat/pkg-1", commit=False)
-        with os_environ(GIT_EDITOR="sed -i '1s/1/2/'"), patch(
-            "sys.argv", self.args + ["-u", "-t", path]
-        ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+        with (
+            os_environ(GIT_EDITOR="sed -i '1s/1/2/'"),
+            patch("sys.argv", self.args + ["-u", "-t", path]),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         assert excinfo.value.code == 0
         commit_msg = git_repo.log(["-1", "--pretty=tformat:%B", "HEAD"])
@@ -251,9 +288,11 @@ class TestPkgdevCommit:
         for i, opt in enumerate(["-M", "--message-template"], 1):
             repo.create_ebuild(f"cat/pkg-{i}")
             git_repo.add_all(f"cat/pkg-{i}", commit=False)
-            with patch("sys.argv", self.args + ["-u", opt, path]), pytest.raises(
-                SystemExit
-            ) as excinfo, chdir(git_repo.path):
+            with (
+                patch("sys.argv", self.args + ["-u", opt, path]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             commit_msg = git_repo.log(["-1", "--pretty=tformat:%B", "HEAD"])
@@ -274,9 +313,11 @@ class TestPkgdevCommit:
         for i, opt in enumerate(["-M", "--message-template"], 3):
             repo.create_ebuild(f"cat/pkg-{i}")
             git_repo.add_all(f"cat/pkg-{i}", commit=False)
-            with patch("sys.argv", self.args + ["-u", opt, path]), pytest.raises(
-                SystemExit
-            ) as excinfo, chdir(git_repo.path):
+            with (
+                patch("sys.argv", self.args + ["-u", opt, path]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             commit_msg = git_repo.log(["-1", "--pretty=tformat:%B", "HEAD"])
@@ -289,9 +330,11 @@ class TestPkgdevCommit:
         for i, opt in enumerate(["-M", "--message-template"], 5):
             repo.create_ebuild(f"cat/pkg-{i}")
             git_repo.add_all(f"cat/pkg-{i}", commit=False)
-            with patch("sys.argv", self.args + ["-u", opt, path]), pytest.raises(
-                SystemExit
-            ) as excinfo, chdir(git_repo.path):
+            with (
+                patch("sys.argv", self.args + ["-u", opt, path]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 2
             out, err = capsys.readouterr()
@@ -305,9 +348,11 @@ class TestPkgdevCommit:
         with open(ebuild_path, "a+") as f:
             f.write("# comment\n")
 
-        with patch("sys.argv", self.args + ["-u", "-m", "msg"]), pytest.raises(
-            SystemExit
-        ) as excinfo, chdir(git_repo.path):
+        with (
+            patch("sys.argv", self.args + ["-u", "-m", "msg"]),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         assert excinfo.value.code == 0
         out, err = capsys.readouterr()
@@ -323,9 +368,11 @@ class TestPkgdevCommit:
         with open(ebuild_path, "a+") as f:
             f.write("# comment\n")
 
-        with patch("sys.argv", self.args + ["-u", "-m", "prefix: msg"]), pytest.raises(
-            SystemExit
-        ) as excinfo, chdir(git_repo.path):
+        with (
+            patch("sys.argv", self.args + ["-u", "-m", "prefix: msg"]),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         assert excinfo.value.code == 0
         out, err = capsys.readouterr()
@@ -341,9 +388,12 @@ class TestPkgdevCommit:
         with open(ebuild_path, "a+") as f:
             f.write("# comment\n")
 
-        with os_environ(GIT_EDITOR="sed -i '1s/$/commit/'"), patch(
-            "sys.argv", self.args + ["-u"]
-        ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+        with (
+            os_environ(GIT_EDITOR="sed -i '1s/$/commit/'"),
+            patch("sys.argv", self.args + ["-u"]),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         assert excinfo.value.code == 0
         out, err = capsys.readouterr()
@@ -358,9 +408,11 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit():
-            with patch("sys.argv", self.args + ["-a", "-m", "msg"]), pytest.raises(
-                SystemExit
-            ) as excinfo, chdir(git_repo.path):
+            with (
+                patch("sys.argv", self.args + ["-a", "-m", "msg"]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             out, err = capsys.readouterr()
@@ -441,9 +493,12 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit():
-            with os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"), patch(
-                "sys.argv", self.args + ["-a"]
-            ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+            with (
+                os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"),
+                patch("sys.argv", self.args + ["-a"]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             out, err = capsys.readouterr()
@@ -592,9 +647,12 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit():
-            with os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"), patch(
-                "sys.argv", self.args + ["-a"]
-            ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+            with (
+                os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"),
+                patch("sys.argv", self.args + ["-a"]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             out, err = capsys.readouterr()
@@ -670,9 +728,12 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit():
-            with os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"), patch(
-                "sys.argv", self.args + ["-a"]
-            ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+            with (
+                os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"),
+                patch("sys.argv", self.args + ["-a"]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             out, err = capsys.readouterr()
@@ -859,9 +920,12 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit(args):
-            with os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"), patch(
-                "sys.argv", self.args + args
-            ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+            with (
+                os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"),
+                patch("sys.argv", self.args + args),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
+            ):
                 self.script()
             assert excinfo.value.code == 0
             out, err = capsys.readouterr()
@@ -886,8 +950,10 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit(args):
-            with patch("sys.argv", self.args + args), pytest.raises(SystemExit) as excinfo, chdir(
-                git_repo.path
+            with (
+                patch("sys.argv", self.args + args),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
             ):
                 self.script()
             assert excinfo.value.code == 0
@@ -928,8 +994,10 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
 
         def commit(args):
-            with patch("sys.argv", self.args + args), pytest.raises(SystemExit) as excinfo, chdir(
-                git_repo.path
+            with (
+                patch("sys.argv", self.args + args),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
             ):
                 self.script()
             assert excinfo.value.code == 0
@@ -1006,8 +1074,10 @@ class TestPkgdevCommit:
         for i, opt in enumerate(["-s", "--scan"], 1):
             repo.create_ebuild(f"cat/pkg-{i}")
             git_repo.add_all(f"cat/pkg-{i}", commit=False)
-            with patch("sys.argv", self.args + [opt]), pytest.raises(SystemExit) as excinfo, chdir(
-                git_repo.path
+            with (
+                patch("sys.argv", self.args + [opt]),
+                pytest.raises(SystemExit) as excinfo,
+                chdir(git_repo.path),
             ):
                 self.script()
             assert excinfo.value.code == 0
@@ -1024,8 +1094,10 @@ class TestPkgdevCommit:
         # verify staged changes via `pkgcheck scan` before creating commit
         repo.create_ebuild("cat/pkg-1", license="")
         git_repo.add_all("cat/pkg-1", commit=False)
-        with patch("sys.argv", self.args + ["--scan"]), pytest.raises(SystemExit) as excinfo, chdir(
-            git_repo.path
+        with (
+            patch("sys.argv", self.args + ["--scan"]),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
         ):
             self.script()
         assert excinfo.value.code == 1
@@ -1043,9 +1115,12 @@ class TestPkgdevCommit:
         )
 
         # ignore failures to create the commit
-        with patch("sys.argv", self.args + ["--scan", "--ask"]), patch(
-            "sys.stdin", StringIO("y\n")
-        ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+        with (
+            patch("sys.argv", self.args + ["--scan", "--ask"]),
+            patch("sys.stdin", StringIO("y\n")),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         assert excinfo.value.code == 0
 
@@ -1066,9 +1141,11 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
         repo.create_ebuild("cat/pkg-1", license="")
         git_repo.add_all("cat/pkg-1", commit=False)
-        with patch(
-            "sys.argv", ["pkgdev", "commit", "--config", config_file] + self.scan_args
-        ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+        with (
+            patch("sys.argv", ["pkgdev", "commit", "--config", config_file] + self.scan_args),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         out, err = capsys.readouterr()
         assert excinfo.value.code == 1
@@ -1092,9 +1169,11 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
         repo.create_ebuild("cat/pkg-1", license="")
         git_repo.add_all("cat/pkg-1", commit=False)
-        with patch(
-            "sys.argv", ["pkgdev", "commit", "--config", config_file] + self.scan_args
-        ), pytest.raises(SystemExit) as excinfo, chdir(git_repo.path):
+        with (
+            patch("sys.argv", ["pkgdev", "commit", "--config", config_file] + self.scan_args),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
+        ):
             self.script()
         out, err = capsys.readouterr()
         assert excinfo.value.code == 1
@@ -1107,8 +1186,10 @@ class TestPkgdevCommit:
         git_repo.add_all("cat/pkg-0")
         repo.create_ebuild("cat/pkg-1", eapi="-1")
         git_repo.add_all("cat/pkg-1", commit=False)
-        with patch("sys.argv", self.args), pytest.raises(SystemExit) as excinfo, chdir(
-            git_repo.path
+        with (
+            patch("sys.argv", self.args),
+            pytest.raises(SystemExit) as excinfo,
+            chdir(git_repo.path),
         ):
             self.script()
         assert excinfo.value.code == 1
